==> vais_speech-1.0.8.tar.gz: lib/repository/network.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:vais_speech/model/audio/audio.dart';
import 'package:vais_speech/model/audio/created_audio_response.dart';
import 'package:vais_speech/model/lyric/lyric_response.dart';
import 'package:vais_speech/model/status.dart';
import 'package:xml/xml.dart' as xml;
import 'package:http/http.dart' as http;
import 'package:vais_speech/model/s3/signature.dart';
import 'package:vais_speech/model/s3/signature_response.dart';

class NetworkRepository {
  static const String DOMAIN = "sohoa-api.vais.vn";
  static const String BASE_URL = "https://$DOMAIN";
  static const String AUTH_PATH = "$BASE_URL/authen/api/v1/auth";
  static const String LOGIN_PATH = "$AUTH_PATH/login";
  static const String REGISTER_PATH = "$AUTH_PATH/registration";
  static const String RESET_PASSWORD_PATH = "$AUTH_PATH/password/reset";
  static const String CHANGE_PASSWORD_PATH = "$AUTH_PATH/password/change";
  static const String USER_INFO_PATH = "$AUTH_PATH/user";
  static const String AUDIO_LIST_PATH = "$BASE_URL/analytic/v1/audios?";
  static const String QUOTA_PATH = "$BASE_URL/analytic/api/v1/apikeys";
  static const String REMOVE_AUDIO_PATH = "$BASE_URL/analytic/v1/audios";
  static const String GET_S3_SIGNATURE_PATH =
      "$BASE_URL/analytic/v1/digitalization/upload-audio";
  static const String CREATE_AUDIO_PATH = "$BASE_URL/analytic/v1/audios";
  static const String EXECUTE_AUDIO_PATH =
      "$BASE_URL/analytic/v1/audios/execute-plan";
  static const String GET_AUDIO_INFO = "$BASE_URL/analytic/v1/audios";
  static const String GET_AUDIO_LYRIC = "$BASE_URL/analytic/v1/texts";

  final String apiKey;

  NetworkRepository({@required this.apiKey});

  Future<String> uploadVideoAndGetAudioId(String path, {String finalName = ''}) {
    return http.post(GET_S3_SIGNATURE_PATH, headers: {'api-key': apiKey}).then(
            (r) async {
              var _s3Signature = SignatureResponse.fromJson(json.decode(r.body));
              var uploadResult = await _upload(_s3Signature.postEndpoint, path, _s3Signature.signature);
              print("Done ${uploadResult.toString()}");

              if (finalName.isEmpty) {
                finalName = "${DateTime.now().millisecondsSinceEpoch}";
              }
              var uploadedAudioId =  await _createAndExecuteAudio(uploadResult["bucket"], uploadResult["key"], finalName);
              print("Upload Success Audio Id With Vais Speech $uploadedAudioId");
              return uploadedAudioId;
            });
  }

  Future<Map<String, String>> _upload(String url, String path, Signature signature) async {
    var uri = Uri.parse(url);
    print("Calling s3 to $url");
    var multipartRequest = http.MultipartRequest("POST", uri)
      ..fields.addAll(signature.toJson())
      ..files.add(await http.MultipartFile.fromPath("file", path));
    print(multipartRequest.toString());
    var streamResponse = await multipartRequest.send();
    var response = await http.Response.fromStream(streamResponse);
    print(response.statusCode);
    print(response.body);
    var afterParsedXml = xml.parse(response.body);
    try {
      var bucket = afterParsedXml
          .findAllElements("PostResponse")
          .toList()[0]
          .findAllElements("Bucket")
          .toList()[0]
          .text;
      var key = afterParsedXml
          .findAllElements("PostResponse")
          .toList()[0]
          .findAllElements("Key")
          .toList()[0]
          .text;
      print("Bucket : $bucket");
      print("Key : $key");
      return {"bucket": bucket, "key": key};
    } catch (e) {
      print(e);
      return null;
    }
  }

  Future<String> _createAndExecuteAudio(String bucket, String key, String name) async {
    var createAudioResponse = await http.post(CREATE_AUDIO_PATH,
        body: {'bucket': bucket, 'key': key, 'name': name, 'source_name': ""},
        headers: {'api-key': apiKey});
    var createdAudioData = AfterUploadedAudioResponse.fromJson(
        json.decode(createAudioResponse.body));
    print("Status Now : ${createdAudioData.status}");
    if (createdAudioData.id != null) {
      var executeAudioResponse = await http.post(EXECUTE_AUDIO_PATH,
          body: {'audio_id': createdAudioData.id}, headers: {'api-key': apiKey});
      var executeAudioData = AfterUploadedAudioResponse.fromJson(
          json.decode(executeAudioResponse.body));
      print("Status Now : ${executeAudioData.status}");
    }
    return createdAudioData.id;
  }

  Future<AudioStatus> getAudioInfo(String audioId) =>
      http.get("$GET_AUDIO_INFO/$audioId?add_audio_url=true", headers: {
        'api-key': apiKey
      }).then((r) => Audio.fromJson(json.decode(r.body)).toStatus);

  Future<TranscriptResponse> getTranscript(String audioId) => http
      .get("$GET_AUDIO_LYRIC?audio_id=$audioId", headers: {'api-key': apiKey})
      .timeout(const Duration(seconds: 30))
      .then((r) async {
        try {
          switch (r.statusCode) {
            case 200:
            case 400:
              return TranscriptResponse.fromJson(json.decode(r.body));
            default:
              var msg = r.body.replaceAll("'", "\"");
              var map = Map<String, dynamic>.from(json.decode(msg));
              return TranscriptResponse(r.statusCode,
                  "${map.keys.elementAt(0).toUpperCase()}: ${map[map.keys.elementAt(0)][0]}");
          }
        } catch (_) {
          return TranscriptResponse.fromJson(json.decode(r.body));
        }
      });
}

==> vais_speech-2.0.1.tar.gz: lib/repository/network.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:vais_speech/model/audio/audio.dart';
import 'package:vais_speech/model/audio/created_audio_response.dart';
import 'package:vais_speech/model/lyric/lyric_response.dart';
import 'package:vais_speech/model/status.dart';
import 'package:xml/xml.dart' as xml;
import 'package:http/http.dart' as http;
import 'package:vais_speech/model/s3/signature.dart';
import 'package:vais_speech/model/s3/signature_response.dart';

class NetworkRepository {
  static const String DOMAIN = "sohoa-api.vais.vn";
  static const String BASE_URL = "https://$DOMAIN";
  static const String AUTH_PATH = "$BASE_URL/authen/api/v1/auth";
  static const String LOGIN_PATH = "$AUTH_PATH/login";
  static const String REGISTER_PATH = "$AUTH_PATH/registration";
  static const String RESET_PASSWORD_PATH = "$AUTH_PATH/password/reset";
  static const String CHANGE_PASSWORD_PATH = "$AUTH_PATH/password/change";
  static const String USER_INFO_PATH = "$AUTH_PATH/user";
  static const String AUDIO_LIST_PATH = "$BASE_URL/analytic/v1/audios?";
  static const String QUOTA_PATH = "$BASE_URL/analytic/api/v1/apikeys";
  static const String REMOVE_AUDIO_PATH = "$BASE_URL/analytic/v1/audios";
  static const String GET_S3_SIGNATURE_PATH =
      "$BASE_URL/analytic/v1/digitalization/upload-audio";
  static const String CREATE_AUDIO_PATH = "$BASE_URL/analytic/v1/audios";
  static const String EXECUTE_AUDIO_PATH =
      "$BASE_URL/analytic/v1/audios/execute-plan";
  static const String GET_AUDIO_INFO = "$BASE_URL/analytic/v1/audios";
  static const String GET_AUDIO_LYRIC = "$BASE_URL/analytic/v1/texts";

  final String? apiKey;

  NetworkRepository({required this.apiKey});

  Future<String?> uploadVideoAndGetAudioId(String path, {String finalName = ''}) {
    return http.post(Uri.parse(GET_S3_SIGNATURE_PATH), headers: {'api-key': apiKey!}).then(
            (r) async {
              var _s3Signature = SignatureResponse.fromJson(json.decode(r.body));
              var uploadResult = await (_upload(_s3Signature.postEndpoint!, path, _s3Signature.signature!) as FutureOr<Map<String, String>>);
              print("Done ${uploadResult.toString()}");

              if (finalName.isEmpty) {
                finalName = "${DateTime.now().millisecondsSinceEpoch}";
              }
              var uploadedAudioId =  await _createAndExecuteAudio(uploadResult["bucket"], uploadResult["key"], finalName);
              print("Upload Success Audio Id With Vais Speech $uploadedAudioId");
              return uploadedAudioId;
            });
  }

  Future<Map<String, String>?> _upload(String url, String path, Signature signature) async {
    var uri = Uri.parse(url);
    print("Calling s3 to $url");
    var multipartRequest = http.MultipartRequest("POST", uri)
      ..fields.addAll(signature.toJson() as Map<String, String>)
      ..files.add(await http.MultipartFile.fromPath("file", path));
    print(multipartRequest.toString());
    var streamResponse = await multipartRequest.send();
    var response = await http.Response.fromStream(streamResponse);
    print(response.statusCode);
    print(response.body);
    var afterParsedXml = xml.parse(response.body);
    try {
      var bucket = afterParsedXml
          .findAllElements("PostResponse")
          .toList()[0]
          .findAllElements("Bucket")
          .toList()[0]
          .text;
      var key = afterParsedXml
          .findAllElements("PostResponse")
          .toList()[0]
          .findAllElements("Key")
          .toList()[0]
          .text;
      print("Bucket : $bucket");
      print("Key : $key");
      return {"bucket": bucket, "key": key};
    } catch (e) {
      print(e);
      return null;
    }
  }

  Future<String?> _createAndExecuteAudio(String? bucket, String? key, String name) async {
    var createAudioResponse = await http.post(Uri.parse(CREATE_AUDIO_PATH),
        body: {'bucket': bucket, 'key': key, 'name': name, 'source_name': ""},
        headers: {'api-key': apiKey!});
    var createdAudioData = AfterUploadedAudioResponse.fromJson(
        json.decode(createAudioResponse.body));
    print("Status Now : ${createdAudioData.status}");
    if (createdAudioData.id != null) {
      var executeAudioResponse = await http.post(Uri.parse(EXECUTE_AUDIO_PATH),
          body: {'audio_id': createdAudioData.id}, headers: {'api-key': apiKey!});
      var executeAudioData = AfterUploadedAudioResponse.fromJson(
          json.decode(executeAudioResponse.body));
      print("Status Now : ${executeAudioData.status}");
    }
    return createdAudioData.id;
  }

  Future<AudioStatus> getAudioInfo(String audioId) =>
      http.get(Uri.parse("$GET_AUDIO_INFO/$audioId?add_audio_url=true"), headers: {
        'api-key': apiKey!
      }).then((r) => Audio.fromJson(json.decode(r.body)).toStatus);

  Future<TranscriptResponse> getTranscript(String audioId) => http
      .get(Uri.parse("$GET_AUDIO_LYRIC?audio_id=$audioId"), headers: {'api-key': apiKey!})
      .timeout(const Duration(seconds: 30))
      .then((r) async {
        try {
          switch (r.statusCode) {
            case 200:
            case 400:
              return TranscriptResponse.fromJson(json.decode(r.body));
            default:
              var msg = r.body.replaceAll("'", "\"");
              var map = Map<String, dynamic>.from(json.decode(msg));
              return TranscriptResponse(r.statusCode,
                  "${map.keys.elementAt(0).toUpperCase()}: ${map[map.keys.elementAt(0)][0]}");
          }
        } catch (_) {
          return TranscriptResponse.fromJson(json.decode(r.body));
        }
      });
}
